@@ -528,6 +528,7 @@ class App(QWidget):
         hide_mouse: bool = False,
         aspect_ratio: Qt.AspectRatioMode = Qt.IgnoreAspectRatio,
         resize_mode: Qt.TransformationMode = Qt.SmoothTransformation,
+        background_color: str = "black",
         **kwargs,
     ):
         super().__init__()
@@ -544,6 +545,7 @@ class App(QWidget):
         self.label = QLabel(self)
         self.label.setAlignment(Qt.AlignCenter)
         self.label.resize(self.display_width, self.display_height)
+        self.label.setStyleSheet(f"background-color: {background_color}")
 
         self.pixmap = QPixmap(self.width(), self.height())
         self.label.setPixmap(self.pixmap)
@@ -632,6 +634,7 @@ class App(QWidget):
 @click.command()
 @click.option(
     "--folder",
+    metavar="DIRECTORY",
     default=FOLDER_PATH,
     type=click.Path(exists=True, file_okay=False),
     help="Set slides folder.",
@@ -672,6 +675,7 @@ def _list_scenes(folder) -> List[str]:
 @config_path_option
 @click.option(
     "--folder",
+    metavar="DIRECTORY",
     default=FOLDER_PATH,
     type=click.Path(exists=True, file_okay=False),
     help="Set slides folder.",
@@ -688,6 +692,7 @@ def _list_scenes(folder) -> List[str]:
 @click.option(
     "-r",
     "--resolution",
+    metavar="<WIDTH HEIGHT>",
     type=(int, int),
     default=(1920, 1080),
     help="Window resolution WIDTH HEIGHT used if fullscreen is not set. You may manually resize the window afterward.",
@@ -697,6 +702,7 @@ def _list_scenes(folder) -> List[str]:
     "--to",
     "--record-to",
     "record_to",
+    metavar="FILE",
     type=click.Path(dir_okay=False),
     default=None,
     help="If set, the presentation will be recorded into a AVI video file with given name.",
@@ -725,6 +731,16 @@ def _list_scenes(folder) -> List[str]:
     help="Set the resize (i.e., transformation) mode to be used when rescaling video.",
     show_default=True,
 )
+@click.option(
+    "--background-color",
+    "--bgcolor",
+    "background_color",
+    metavar="COLOR",
+    type=str,
+    default="black",
+    help='Set the background color for borders when using "keep" resize mode. Can be any valid CSS color, e.g., "green", "#FF6500" or "rgba(255, 255, 0, .5)".',
+    show_default=True,
+)
 @click.help_option("-h", "--help")
 @verbosity_option
 def present(
@@ -740,6 +756,7 @@ def present(
     hide_mouse,
     aspect_ratio,
     resize_mode,
+    background_color,
 ) -> None:
     """
     Present SCENE(s), one at a time, in order.
@@ -832,6 +849,7 @@ def present(
         hide_mouse=hide_mouse,
         aspect_ratio=ASPECT_RATIO_MODES[aspect_ratio],
         resize_mode=RESIZE_MODES[resize_mode],
+        background_color=background_color,
     )
     a.show()
     sys.exit(app.exec_())
